@@ -1,17 +1,19 @@
-""" Handle JSON lazy. """
+""" Handle JSON lazily. """
+from pathlib import Path
 from typing import Dict
 from typing import BinaryIO
 from typing import Iterable
-from typing import Union
+from typing import Optional, Union
 
 import ijson
 
 from json_streams import jsonlib
+from json_streams import utils
 from json_streams.utils import to_bytes
 
 
 def dump(data: Union[Dict, Iterable], fp: BinaryIO):
-    """ Dump array to a file object.
+    """Dump array to a file object.
 
     Parameters
     ----------
@@ -84,15 +86,56 @@ def load_eager(fp: BinaryIO):
         return data
 
 
-def load_from_file(file_name: str, *, file_mode: str = None):
+def load_from_file(file_name: Path, *, file_mode: Optional[str] = None):
     if not file_mode:
         file_mode = "br"
-    with open(file_name, "br") as fp:
+
+    assert "b" in file_mode
+    with open(file_name, file_mode) as fp:
         yield from load(fp)
 
 
-def dump_to_file(gen: Iterable, file_name: str, *, file_mode: str = None):
+def dump_to_file(gen: Iterable, file_name: Path, *, file_mode: str = None):
     if not file_mode:
         file_mode = "bw"
-    with open(file_name, "bw") as fp:
+    assert "b" in file_mode
+    with open(file_name, file_mode) as fp:
         return dump(gen, fp)
+
+
+def sink(fp: BinaryIO):
+    return utils.Sink(json_sink(fp))
+
+
+def sink_from_file(file_name: Path, *, file_mode: str = None):
+    if not file_mode:
+        file_mode = "bw"
+    assert "b" in file_mode
+    fp = open(file_name, file_mode)
+    return utils.Sink(json_sink(fp, close_file=True))
+
+
+def json_sink(fp: BinaryIO, *, close_file: bool = False):
+    is_first_value = True
+    first_value = None
+    try:
+        while True:
+            value = yield
+            if is_first_value and first_value:
+                fp.write(b"[\n")
+                fp.write(to_bytes(jsonlib.dumps(first_value)))
+                is_first_value = False
+                fp.write(b",\n")
+                fp.write(to_bytes(jsonlib.dumps(value)))
+            elif is_first_value:
+                first_value = value
+            else:
+                fp.write(b",\n")
+                fp.write(to_bytes(jsonlib.dumps(value)))
+    except GeneratorExit:
+        if is_first_value and first_value:
+            fp.write(to_bytes(jsonlib.dumps(first_value)))
+        else:
+            fp.write(b"\n]")
+    if close_file:
+        fp.close()
